# Changelog

<!--next-version-placeholder-->

## v0.10.0 (2021-11-08)
### Feature
* Test pypi release ([`2edb768`](https://github.com/F-Secure/change-analyzer/commit/2edb7685ed457b753a2440567f87ab5f116b1eca))

## v0.9.1 (2021-11-08)
### Fix
* Fix pypi publish ([`006ea92`](https://github.com/F-Secure/change-analyzer/commit/006ea9262624ab51e3a2fad5185b1cd3d7283c2f))

## v0.9.0 (2021-11-08)
### Feature
* Enable pypi publish ([`2cd03db`](https://github.com/F-Secure/change-analyzer/commit/2cd03dbaa1f2addd79beaf3efd83c367e19dbfde))

### Documentation
* Add about section ([`59796be`](https://github.com/F-Secure/change-analyzer/commit/59796bee5738679316bbcb2db237af4a7f0e9054))

## v0.8.0 (2021-11-03)
### Feature
* Enrich page source with data from driver ([`8e0b429`](https://github.com/F-Secure/change-analyzer/commit/8e0b429b1687f280290d13e836899d4280e7b3a1))

## v0.7.0 (2021-10-29)
### Feature
* Save the screenshot using body element ([`0c79a4e`](https://github.com/F-Secure/change-analyzer/commit/0c79a4e3738036d47c3408350e55e5505f5e47dd))
* Add capability to start the browser maximized ([`4260597`](https://github.com/F-Secure/change-analyzer/commit/426059788537cc06df113457844d897e5c7f34e2))
* Record web elements ([`68f55da`](https://github.com/F-Secure/change-analyzer/commit/68f55da2c7d67f830f894359e1f9b456883ebfa8))
* Contain supported diffs ([`ad66df3`](https://github.com/F-Secure/change-analyzer/commit/ad66df335f30ed7b8056096d310aa8884ceb5f9a))

### Fix
* Fix diff validation ([`c7946cd`](https://github.com/F-Secure/change-analyzer/commit/c7946cd61dc50280c3db047b8f98556058d8cc59))

## v0.6.0 (2021-10-20)
### Feature
* Add validation for each diff ([`b2160e0`](https://github.com/F-Secure/change-analyzer/commit/b2160e09bf313ef4aa3569e24540c4ba82f59783))

## v0.5.1 (2021-10-19)
### Fix
* Add various fixes based on review comments ([`fd06d5d`](https://github.com/F-Secure/change-analyzer/commit/fd06d5d398508200036f9943c5a61d4b58460680))

## v0.5.0 (2021-10-15)
### Feature
* Add dockerfile and dependencies ([`ad640c7`](https://github.com/F-Secure/change-analyzer/commit/ad640c74d85f3b63a489888d8fe13d86b9d62499))

## v0.4.2 (2021-10-15)
### Fix
* Add config for semantic-release ([`7027f1f`](https://github.com/F-Secure/change-analyzer/commit/7027f1f7a4c77695fd5dfe75062c3ebb46ece78b))

## v0.4.1 (2021-10-15)
### Fix
* Add python3-setuptools package to publish action ([`4d3f0f3`](https://github.com/F-Secure/change-analyzer/commit/4d3f0f3af0aa73661251664bab5ab1bfdf42bbf1))

## v0.4.0 (2021-10-14)
### Feature
* Enable github releasing ([`c42060a`](https://github.com/F-Secure/change-analyzer/commit/c42060a3c1b5446240a64ba8b5f3cd96b9ee8319))

## v0.3.0 (2021-10-14)
### Feature
* Save merged dataframe as zip ([`54a96c5`](https://github.com/F-Secure/change-analyzer/commit/54a96c57c8eceb029315957be4adf8684cc2bc9d))

## v0.2.4 (2021-10-14)
### Fix
* Fix the case when xmls were nan ([`df6d18e`](https://github.com/F-Secure/change-analyzer/commit/df6d18e84410384f8cdda088df67e0c2c6b2bedb))

## v0.2.3 (2021-10-14)
### Fix
* Fix setup.py readme import issue ([`5d5597c`](https://github.com/F-Secure/change-analyzer/commit/5d5597c099d8729df7d84a779acfcce9eb2b5941))

## v0.2.2 (2021-10-13)
### Fix
* Fix large width for report images on web platform ([`a33aafa`](https://github.com/F-Secure/change-analyzer/commit/a33aafa09fa4bd027fbb663afb511c240e777172))

### Documentation
* Fix of acknowledgement section to README.md ([`6379688`](https://github.com/F-Secure/change-analyzer/commit/6379688ba3eec11239002559e7efd1db4ece7f16))
* Added acknowledgement section to README.md ([`1f9f0b7`](https://github.com/F-Secure/change-analyzer/commit/1f9f0b7959fe47f6b84c3d0b08e1f68833b1c332))

## v0.2.1 (2021-10-13)
### Fix
* Fix dataframe merge ([`1c41875`](https://github.com/F-Secure/change-analyzer/commit/1c41875e2fbf12b0ed78590c4e40a8732000e6cd))

## v0.2.0 (2021-10-12)
### Feature
* Add highlighting diff on elements based on xmldiff ([`00c0c53`](https://github.com/F-Secure/change-analyzer/commit/00c0c53a82662546f317e44c863bf4a8d58d80c9))

## v0.1.1 (2021-10-12)
### Fix
* Add template to install package ([`990bfd1`](https://github.com/F-Secure/change-analyzer/commit/990bfd1027a9fd36239b3495ef4408b2b99333f6))

### Documentation
* Add support for Conda environment ([`b3d3ee9`](https://github.com/F-Secure/change-analyzer/commit/b3d3ee952f13e20f6268f61e975c6c3c3318b065))

## v0.1.0 (2021-10-08)
### Feature
* Initialize project to github ([`e352602`](https://github.com/F-Secure/change-analyzer/commit/e3526023eceb7de77ef28b64afc13ca65b5feccb))
